@@ -149,4 +149,27 @@ if(run.apsimx.edit.soil.soilwat){
                  node = "Soil", soil.child = "SoilWater", 
                  parm = "SummerCona")
   
+}
+
+## TEsting Report feature
+if(run.apsimx.edit){
+  
+ ex.dir <- auto_detect_apsimx_examples()
+ 
+ inspect_apsimx("Wheat.apsimx", src.dir = ex.dir, node = "Report")
+ 
+ edit_apsimx("Wheat.apsimx", src.dir = ex.dir,
+             node = "Report", wrt.dir = tmp.dir,
+             parm = "VariableNames",
+             value = "[Soil].esw")
+ 
+ inspect_apsimx("Wheat-edited.apsimx", src.dir = tmp.dir, node = "Report")
+ 
+ edit_apsimx("Wheat.apsimx", src.dir = ex.dir,
+             node = "Report", wrt.dir = tmp.dir,
+             parm = "EventNames",
+             value = "[Wheat].EndOfDay")
+ 
+ inspect_apsimx("Wheat-edited.apsimx", src.dir = tmp.dir, node = "Report")
+  
 }
\ No newline at end of file
